@@ -157,40 +157,24 @@ class BaseDefinition(db.Model, InitBase, DBBase):
     def by_key(
             cls, key: Union[BaseKey, str],
             language: str = None,
-            case_sensitive: bool = False,
-            partial_results: bool = False,
-    ) -> BaseQuery:
+            case_sensitive: bool = False) -> BaseQuery:
         """Definition.Query filtered by specified key
 
         Args:
           key: Union[BaseKey, str]:
           language: str: Language of key (Default value = None)
           case_sensitive: bool:  (Default value = False)
-          partial_results: bool:  (Default value = False)
 
         Returns:
           BaseQuery
 
         """
 
-        key = BaseKey.word if isinstance(key, BaseKey) else str(key)
+        key = (BaseKey.word if isinstance(key, BaseKey) else str(key)).replace("*", "%")
         request = cls.query.join(t_connect_keys, BaseKey).order_by(BaseKey.word)
 
         if language:
             request = request.filter(BaseKey.language == language)
 
-        if case_sensitive:
-            return cls.__case_sensitive_filter(key, request, partial_results)
-        return cls.__case_insensitive_filter(key, request, partial_results)
-
-    @staticmethod
-    def __case_sensitive_filter(
-            key: str, request: BaseQuery, partial_results: bool) -> BaseQuery:
-        return request.filter(BaseKey.word.like(f"{key}%")) \
-            if partial_results else request.filter(BaseKey.word == key)
-
-    @staticmethod
-    def __case_insensitive_filter(
-            key: str, request: BaseQuery, partial_results: bool) -> BaseQuery:
-        return request.filter(BaseKey.word.ilike(f"{key}%")) \
-            if partial_results else request.filter(BaseKey.word.ilike(key))
+        return request.filter(
+            BaseKey.word.like(key) if case_sensitive else BaseKey.word.ilike(key))
